.. :Detector:

Detector
========

.. currentmodule:: Detector



.. autosummary::
   :nosignatures:

    Detector.Detector
    Detector.Detector.__init__
    Detector.Detector.plot
    Detector.TubeDetector1D
    Detector.TubeDetector1D.__init__
    Detector.TubeDetector1D.plot
    Detector.TubeDetector1D.getPixelPositions
    


Detector Object and Methods
---------------------------


.. automodule:: Detector

.. _Detector:

.. autoclass:: Detector
    :members:

    .. automethod:: __init__


TubeDetector1D Object and Methods
---------------------------------


.. _TubeDetector1D:

.. autoclass:: TubeDetector1D
    :members:

    .. automethod:: __init__


